<?php
/**
---------------------------------------------------------------------------------------------------
Diese Template-Engine erzeugt einen One-Pager auf Basis einer YAML-Datei, in der alle Beiträge
gespeichert sind. Die Beiträge können unterschiedliche Templates für die Anzeigeform auf der
Startseite haben. Für die Darstellung als Beitrag ist das Template 'post.html' zwingend anzulegen.
---------------------------------------------------------------------------------------------------
*/
define('VERSION', '2.4.4');

require('core/Dipper.php');
require('core/Parsedown.php');
require('core/ParsedownExtra.php');

/**
---------------------------------------------------------------------------------------------------
Hauptsteuerung und Weiche die entscheidet, ob der Index oder ein Beitrag aufgerufen wurde
*/
if(explode('/', $_SERVER['REQUEST_URI'])[1])
{
    $slug = explode('/', $_SERVER['REQUEST_URI'])[1];
    $slug = strip_tags($slug);
    $slug = str_replace(array('%','&','<','.php'), '' , $slug);
    set_post($slug);
} else {
    set_index();
}

/**
---------------------------------------------------------------------------------------------------
Die Version 2 geht einen anderen Weg der Verarbeitung. Das Template eines jeden YAML-Beitrags wird
geladen und die dortigen Tokens mit einer RegEx ermittelt und die dazugehörigen Daten aus der YAML
Datei geholt. Diese Vorgehensweise erweist sich als etwas sinnvoller und logischer als in Version 1
Tokens dürfen buchstaben a-z, A-Z und '-' Striche als Trenner enthalten, jedoch keine Zahlen.
---------------------------------------------------------------------------------------------------
*/
function set_index()
{
    $yml_structure = Dipper::parse(file_get_contents('content/content.txt'));
	$template	   = '';
  	$pde           = new Parsedown();

	foreach($yml_structure as $key => $structure)
    {
		//if(!$structure['hidden'])
        if($structure['template'])
    	{
			$template = file_get_contents('templates/'.$structure['template']);
		
			preg_match_all('/{([0-9a-zA-Z\-]*)}/', $template, $matches);

			foreach($matches[1] as $token)
			{
          		if ($token == 'content') 
            	{
					// den Token {content} als MD parsen
              		$template = str_replace('{'.$token.'}', $pde->parse($structure[$token]), $template);
            	} 
          		elseif ($token == 'slug') 
            	{
					// {slug} ist kein YAML-Attribute und wird aus dem Schlüssel erzeugt
              		$template = str_replace('{slug}', $key, $template);
            	} 
          		else 
            	{
					// alle anderen Token des Templates aus der YAML-Struktur befüllen
          			$template = str_replace('{'.$token.'}', $structure[$token], $template);
            	}
            }
        echo $template;
		}
	}
}

/**
---------------------------------------------------------------------------------------------------
Baut einen einzelnen Beitrag auf, den der Leser angeklickt hat.
---------------------------------------------------------------------------------------------------
*/
function set_post($slug)
{
    $yml_structure = Dipper::parse(file_get_contents('content/content.txt'));
	$template      = file_get_contents('templates/post.html');
  	$pde           = new ParsedownExtra();
  
	if (!isset($yml_structure[$slug])) error_404(); // wenn der SLUG nicht in YAML Datei existiert -> 404

  	preg_match_all('/{([0-9a-zA-Z\-]*)}/', $template, $matches);

	foreach($matches[1] as $token)
	{ 
		if($token == 'content') 
		{
          	// Content zuvor als MD parsen
			$template = str_replace('{'.$token.'}', $pde->parse($yml_structure[$slug][$token]), $template);
		} else {
          	// alles andere, normal ersetzen
			$template = str_replace('{'.$token.'}', $yml_structure[$slug][$token], $template);
		}
	}
	echo $template;
}

/**
---------------------------------------------------------------------------------------------------
Sendet einen Error 404 an den Aufrufer.
---------------------------------------------------------------------------------------------------
*/
function error_404()
{
	header("HTTP/1.1 404");
	echo file_get_contents('templates/error-404.html');
	exit();
}

?>